@@ -335,7 +335,6 @@ class QAMProxy:
         """
         # magic method dispatcher
         logger.debug('Recursion: ' + name)
-        time.sleep(1)
         return _Method(self.__request, name)
 
 
@@ -529,6 +528,7 @@ class ConsumerThread(Thread):
                                        password=amqp_credentials.password,
                                        virtual_host=amqp_credentials.vhost,
                                        ssl=amqp_credentials.ssl)
+            self.amqpconn.connect()
         except Exception:
             logger.exception('Init BrokerConnection in ConsumerThread')
             raise
