@@ -226,6 +226,7 @@ class QAMServer:
     """
     while not self.kill:
     #def execute_method(message_data, message):
+        try:
           message = self.consumer.fetch()
           if message != None:
                 message_data = message.payload
@@ -238,6 +239,9 @@ class QAMServer:
                 execute_method_thread.start()
           else:
                 time.sleep(0.1)
+        except Exception:
+            logger.exception('Exception: Connection Lost during fetch')
+            self.amqpconn.connect()
     self.finished = True
 
 
